==> eam-wshub-proxyclient-11.5-4-sources.jar: net/datastream/schemas/mp_fields/EVENTPOINTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour EVENTPOINTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="EVENTPOINTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EVENTPOINTCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EVENTPOINTID_Type", propOrder = {
    "eventpointcode"
})
public class EVENTPOINTID_Type {

    @XmlElement(name = "EVENTPOINTCODE", required = true)
    protected String eventpointcode;

    /**
     * Obtient la valeur de la propriété eventpointcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEVENTPOINTCODE() {
        return eventpointcode;
    }

    /**
     * Définit la valeur de la propriété eventpointcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEVENTPOINTCODE(String value) {
        this.eventpointcode = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/EVENTPOINTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for EVENTPOINTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="EVENTPOINTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EVENTPOINTCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EVENTPOINTID_Type", propOrder = {
    "eventpointcode"
})
public class EVENTPOINTID_Type {

    @XmlElement(name = "EVENTPOINTCODE", required = true)
    protected String eventpointcode;

    /**
     * Gets the value of the eventpointcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEVENTPOINTCODE() {
        return eventpointcode;
    }

    /**
     * Sets the value of the eventpointcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEVENTPOINTCODE(String value) {
        this.eventpointcode = value;
    }

}
